package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````V!<``#0```"``0$```(`!30`(``)
M`"@`&P`:``$``'`HB@``*(H``"B*```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$````````````````````TB@``-(H```4```````$`
M`0```*S]``"L_0$`K/T!`)0"``"H$@``!@```````0`"````M/T``+3]`0"T
M_0$`$`$``!`!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DK/T`
M`*S]`0"L_0$`5`(``%0"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`(9A=#-MA22E7#!>^I'(;(U_B!>K!````!`````!
M````1TY5```````#`````@`````````1````3`````@````(`````9`0!"5`
M!(`H@``%H(90A(`!```+*`2,.*`218H```A,````30```%````!4````50``
M`%T```!>````7P```&$```!B````9````&4```!F````9P```&H`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NV=E0\E"#_Y`[59-1\V7%8'.)'Q@%"
M^M>'K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>OS&9"1=7LB0=PTPT4
MXI[:S>.>,V+;[16,)<P-.I<+?ZF<F[[:5QO@IP(*:QJ>4*/@^TD`````````
M`````````````````"P2`````````P`+``````````(```````,`%@!``@``
M```````````2````U`(`````````````$@```*@"`````````````"(```#M
M`@`````````````1````E`,`````````````$@````$``````````````"``
M``"F`0`````````````2````AP(`````````````$@```,4"````````````
M`!(```#X```````````````2````"0,`````````````$0```%L"````````
M`````!(```!<`0`````````````2````8@(`````````````$@```$<"````
M`````````!(```!T```````````````2````\P``````````````$@```&H"
M`````````````!(````D`@`````````````2````Z@$`````````````$@``
M`/<"`````````````!(```!C`@`````````````2````^P$`````````````
M$@````@"`````````````!(```#1```````````````1````3@$`````````
M````$@```+,``````````````!$````<`0`````````````2````C@(`````
M````````$@```(`"`````````````!$```"*`0`````````````2````L@$`
M````````````$@```'<!`````````````!(```!X`@`````````````2````
MJP$`````````````$@```(,!`````````````!(```#;`@`````````````2
M````*@$`````````````$@```!T``````````````"`````=`@``````````
M```2````U`$`````````````$@```#("`````````````!(```!4````````
M```````2````EP(`````````````$@```(,``````````````!(```"5`0``
M```````````2````MP(`````````````$@```(\``````````````!(```!#
M`0`````````````2`````@(`````````````$@```#D"`````````````!(`
M```)`0`````````````2````1@``````````````$@```/T`````````````
M`!(```!L`0`````````````2````30(`````````````$@```,``````````
M`````!(````6`@`````````````2````S0(`````````````$@```-P`````
M`````````!(````K`@`````````````2````8P``````````````$@```.X"
M`````````````"$```">`@`````````````2````I```````````````$@``
M`#H!`````````````!(````L```````````````@````[P(`````````````
M$0```-D!`````````````!(````0`@`````````````2````S@$`````````
M````$@```.$!`````````````!(```"Z`0`````````````2````L0,``%00
M`@``````$``7`)T#```<.```<`$``!(`#0#5`P``_"P``%P(```2``T`Z`(`
M`"@5``"P`@``$@`-`&,#``"D(0``!````!(`#0!T`P``0``"```````0`!<`
M<00``*@A``"4`@``$@`-`*<$``!8-0``Q`(``!(`#0!=!```0``"```````0
M`!<`O`,``#PD```H````$@`-`.(#```P1@``&`$``!(`#0#Z`P``($D```0`
M```1``\`.00``%00`@``````$``7`#X$``!4$`(``````!``%P!I!```6"``
M`%`````2``T`?@0``)0K``!H`0``$@`-`)`$``#`*@``O````!(`#0#M`P``
M```"```````0`!8`R0,``&0D```D`0``$@`-`*D#``!```(``````!``%@`O
M!```/``"``0````1`!8`4P,```!)```$````$@`-`!\$``"@2```8````!(`
M#0#S`P``V!<````````2``T`G@0``*!%``"0````$@`-`.\#``````(`````
M`"``%@""`P``?"L``!@````2``T`L`,``%00`@``````$``7``D$``"H(```
M_````!(`#0!3!```2$<``%@!```2``T`1@0``(@E```X!0``$@`-``!?251-
M7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R
M96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN
M:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?
M<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!097)L7V-R;V%K
M7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P
M97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%]?97)R
M;F]?;&]C871I;VX`<F5A9`!O<&5N-C0`;'-E96LV-`!P=&AR96%D7V=E='-P
M96-I9FEC`&-L;W-E`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H
M:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?
M7V9P<FEN=&9?8VAK`&UE;6-P>0!L<W1A=#8T`%]?<W1R;F-P>5]C:&L`;W!E
M;F1I<@!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R96%D9&ER-C0`
M7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S
M=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?
M871F;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XS-`!L:6)P
M=&AR96%D+G-O+C``;&EB8RYS;RXV`&QD+6QI;G5X+G-O+C,`7U]L:6)C7V-S
M=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`7U]B<W-?<W1A<G1?7P!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A=&$`7U]B<W-?
M96YD7U\`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!S
M:&%?=7!D871E`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD
M`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X
M<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV
M7V-L96%N`'-H85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R
M+C0`1TQ)0D-?,BXS,P`````````"``(``@`"``(``0`#``(``@`"``0``@`!
M``4``@`!``$``@`"``(``@`%``(``@`!``$``0`!``(``@`!``,``0`"``,`
M`@`"``$``0`"``(``@`!``(``0`#``(``0`!``(``@`!``$``0`!``(``0`"
M``(``0`"``$``@`"``$``0`!``(``@`"``,``@`#``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!`$4#```0````(````!1I:0T```0`O00````````!``$`*P,``!``
M```@````%&EI#0```P"]!`````````$``@`[`P``$`````````"SD98&```%
M`,<$```0````%&EI#0```@"]!````````*S]`0`7````L/T!`!<```#$_P$`
M%P```.C_`0`7````\/\!`!<````$``(`%P````P``@`7````$``"`!<````8
M``(`%P```!P``@`7````(``"`!<````D``(`%P```"@``@`7````,``"`!<`
M```T``(`%P```#P``@`7````R/\!`!4%``#,_P$`%0@``-#_`0`5#0``U/\!
M`!4/``#8_P$`%1L``-S_`0`5'0``X/\!`!4@``#D_P$`%2D``.S_`0`5-@``
M]/\!`!5```#X_P$`%44``/S_`0`51@``T/X!`!8#``#4_@$`%@0``-C^`0`6
M!0``W/X!`!8'``#@_@$`%@D``.3^`0`6"@``Z/X!`!8+``#L_@$`%@P``/#^
M`0`6#@``]/X!`!80``#X_@$`%A$``/S^`0`6$@```/\!`!83```$_P$`%A0`
M``C_`0`6%0``#/\!`!86```0_P$`%A<``!3_`0`6&```&/\!`!89```<_P$`
M%AH``"#_`0`6'```)/\!`!8>```H_P$`%A\``"S_`0`6(0``,/\!`!8B```T
M_P$`%B,``#C_`0`6)```//\!`!8E``!`_P$`%B8``$3_`0`6)P``2/\!`!8H
M``!,_P$`%BD``%#_`0`6*@``5/\!`!8K``!8_P$`%BP``%S_`0`6+0``8/\!
M`!8N``!D_P$`%B\``&C_`0`6,```;/\!`!8Q``!P_P$`%C(``'3_`0`6,P``
M>/\!`!8T``!\_P$`%C4``(#_`0`6-P``A/\!`!8X``"(_P$`%CD``(S_`0`6
M.@``D/\!`!8[``"4_P$`%CP``)C_`0`6/0``G/\!`!8^``"@_P$`%C\``*3_
M`0`60@``J/\!`!9#``"L_P$`%D0``+#_`0`61P``M/\!`!9(``"X_P$`%DD`
M`+S_`0`62@``P/\!`!9+```(0"WI?@$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[E
M?.P!``#&C^(>RHSB?/R\Y0#&C^(>RHSB=/R\Y0#&C^(>RHSB;/R\Y0#&C^(>
MRHSB9/R\Y0#&C^(>RHSB7/R\Y0#&C^(>RHSB5/R\Y0#&C^(>RHSB3/R\Y0#&
MC^(>RHSB1/R\Y0#&C^(>RHSB//R\Y0#&C^(>RHSB-/R\Y0#&C^(>RHSB+/R\
MY0#&C^(>RHSB)/R\Y0#&C^(>RHSB'/R\Y0#&C^(>RHSB%/R\Y0#&C^(>RHSB
M#/R\Y0#&C^(>RHSB!/R\Y0#&C^(>RHSB_/N\Y0#&C^(>RHSB]/N\Y0#&C^(>
MRHSB[/N\Y0#&C^(>RHSBY/N\Y0#&C^(>RHSBW/N\Y0#&C^(>RHSBU/N\Y0#&
MC^(>RHSBS/N\Y0#&C^(>RHSBQ/N\Y0#&C^(>RHSBO/N\Y0#&C^(>RHSBM/N\
MY0#&C^(>RHSBK/N\Y0#&C^(>RHSBI/N\Y0#&C^(>RHSBG/N\Y0#&C^(>RHSB
ME/N\Y0#&C^(>RHSBC/N\Y0#&C^(>RHSBA/N\Y0#&C^(>RHSB?/N\Y0#&C^(>
MRHSB=/N\Y0#&C^(>RHSB;/N\Y0#&C^(>RHSB9/N\Y0#&C^(>RHSB7/N\Y0#&
MC^(>RHSB5/N\Y0#&C^(>RHSB3/N\Y0#&C^(>RHSB1/N\Y0#&C^(>RHSB//N\
MY0#&C^(>RHSB-/N\Y0#&C^(>RHSB+/N\Y0#&C^(>RHSB)/N\Y0#&C^(>RHSB
M'/N\Y0#&C^(>RHSB%/N\Y0#&C^(>RHSB#/N\Y0#&C^(>RHSB!/N\Y0#&C^(>
MRHSB_/J\Y0#&C^(>RHSB]/J\Y0#&C^(>RHSB[/J\Y0#&C^(>RHSBY/J\Y0#&
MC^(>RHSBW/J\Y0#&C^(>RHSBU/J\Y0#&C^(>RHSBS/J\Y0#&C^(>RHSBQ/J\
MY0#&C^(>RHSBO/J\Y0#&C^(>RHSBM/J\Y0#&C^(>RHSBK/J\Y0#&C^(>RHSB
MI/J\Y0#&C^(>RHSBG/J\Y5S"G^5<,I_E<$`MZ0S`C^`@T$WB%`"-Y1`0C>4,
M((WE`S"<YQ0`C>(0$(WB#""-XC1"G^4`,)/E'#"-Y0`PH..@___K)"*?Y01`
MC^`@,I_E`B"4YP,`E.<"$*#AW@P`ZQ`RG^4#,)3G`%#3Y0``5>-7```*`#*?
MY0-`E.<``)3EV___Z\8CT.4`,*#A`B""X\8CP^4``)3EU?__ZQ1`G>4$((3B
M!P%RXP-`A.+&,]#E`3"#X\8SP.5C``"*`@&@X6+__^NT(9_EM,&?Y1`0G>4"
M((_@`""2Y0S`C^`44)WE`0!5XP`PH.$$`(SE``"1Y0@@@^6,(9_E``"#Y0(@
MC^`,((/E@"&?Y0(@C^`$((/E3@``V@0`0>(,P(/B!0&`X`3@L>4$X*SE``!1
MX?O__QH#$(7B``"@XU!1G^4``(WE`0&#YT@1G^4%4(_@!""@X0P`E>4!$(_@
M>___ZP!`4.(H```*+%&?Y1A@C>(%4(_@#`"5Y2;__^L<`9_E!A"@X0``C^"H
M``#K``!0XR$```H(,9_E`S"/X`P`D^4$___K8___Z_@@G^6X,)_E`B"/X`,P
MDN<`()/E'#"=Y0(@,^``,*#C(P``&@0`H.$@T(WB<("]Z!?__^O(()_E`B"/
MX```4.,,`(+E&P``"NW^_^N$,)_E`T"4YP``E.5\___K>U?`Y9S__^H,`)7E
M:?__ZP!`H.'2___J"`"5Y0``4.,!```*,@@`Z]C__^IX`)_E!A"@X0``C^![
M``#K``!0XP@`A>71__\*]?__ZDW__^L$$*#CMO__ZM[^_^L!`*#C$O__ZXCI
M`0`,`0``3.D!`"@!```P`0``&`$``!0!```\Z@$`/.H!`(0V``!T-@``S.D!
M`#P)``"HZ0$`R#,``(#I`0#HYP$`..D!`+`R````L*#C`."@XP00G>0-(*#A
M!"`MY00`+>4HH)_E)#"/X@.@BN`@P)_E#,":YP3`+>48,)_E`S":YQ0`G^4`
M`)KGXO[_ZS7__^NDY@$```$``"0!```L`0``%#"?Y10@G^4#,(_@`B"3YP``
M4N,>_R\!W/[_ZH3F`0`@`0``+`"?Y2PPG^4``(_@`S"/X```4^$@,)_E`S"/
MX![_+P$8()_E`C"3YP``4^,>_R\!$_\OX=SG`0#8YP$`4.8!``@!```X`)_E
M.#"?Y0``C^`#,(_@`#!#X*,?H.%#$8'@)#"?Y<$0L.$#,(_@'O\O`1@@G^4"
M,)/G``!3XQ[_+P$3_R_AF.<!`)3G`0``Y@$`-`$``$PPG^5,()_E`S"/X``P
MT^4"((_@``!3XQ[_+Q$X,)_E$$`MZ0,PDN<``%/C`@``"B@PG^4#`)_G3_[_
MZ\K__^L<,)_E`2"@XP,PC^``(,/E$("]Z$CG`0#$Y0$`!`$``.#F`0`(YP$`
MT/__ZLPPG^7P1RWI`)!0X@,PC^`K```*O""?Y0(PD^<`@)/E``!8XR@```H`
M4-GE`7"@X0``5>,]`%43`5"@$P!0H`,1```:`$"8Y0``5.,,```*"&"@X00`
MH.$%(*#A"1"@X<S^_^L``%#C`@``&@4PU.<]`%/C"P``"@1`MN4``%3C\___
M&@0`H.'PA[WH"5"@X0$P]>4``%/C/0!3$_O__QH)4$7@YO__Z@A@1N`!4(7B
M1F&@X05`A.`$`*#A`&"'Y?"'O>@)0*#A[?__Z@A`H.'K___J7.4!`#@!``!D
M(9_E9#&?Y0(@C^#P02WI`S"2YWC03>(`4%#B`#"3Y70PC>4`,*#C`@``"@`P
MU>4``%/C"@``&C0AG^4L,9_E`B"/X`,PDN<`()/E=#"=Y0(@,^``,*#C0@``
M&GC0C>+P@;WH.O[_ZP!`4.+Q__\*`'&?Y0=PC^`$`*#AA?[_ZP``4.,I```*
M$S#0Y1-@@.(N`%/C`@``&@$PUN4``%/C]/__"A,PT.4N`%/C)```"@4`H.$^
M_O_K`("@X08`H.$[_O_K``"(X`(`@.(F_O_K!S"@X0`@X.,!$*#C!&"-Y0!0
MC>4`8*#A0/[_ZP@0C>(&`*#A^_W_ZP$`<.,&`*#A`P``"A@PG>4/.@/B`0E3
MXQ(```KV_?_K!@"@X=/]_^L$`*#A6_[_ZP``4./5__\:!`"@X6G^_^L%`*#A
MU/W_Z[S__^H!,-;E+@!3X]?__QH",-;E``!3X\;__PK3___JIO__Z^O__^K8
M_?_KA.0!``P!``!,Y`$`""\``)`@G^60,)_E`B"/X!!`+>EPT$WB`S"2YPT0
MH.$`0*#A`#"3Y6PPC>4`,*#CMOW_ZP``4.,``*`3!```&A`PG>4/.@/B"@I3
MXP$)4Q,*```*2""?Y4`PG^4"((_@`S"2YP`@D^5L,)WE`B`SX``PH.,'```:
M<-"-XA"`O>@"$*#C!`"@X1O^_^L0#V_AH`*@X>[__^JN_?_K".,!``P!``"X
MX@$`\$,MZ0%@H.$,$9_E##&?Y0':3>(,T$WB`1"/X`,PD><`0*#A`0J-X@0`
M@.(`,)/E`#"`Y0`PH./D`)_E!'"-XN`@G^4``(_@!Q"@X:S]_^O4@)_E"("/
MX`#`4.(6``#:"%"-X@&03.()4(7@!#!5Y0``4^,E```:``!9XPX```H)(*#A
M+Q"@XP<`H.'M_?_K``!0XP@```J0,)_E`S"8YP``D^4(_O_K"3"@X0<@H.$$
M$*#A\OW_ZP8``.IL,)_E`S"8YP``D^7__?_K!B"@X000H.&'_?_K5""?Y3PP
MG^4"((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XP0``!H!VHWB#-"-
MXO"#O>@,D*#AV?__ZF3]_^M4X@$`#`$``"`M``#_#P``&.(!`!0!``",X0$`
M\$<MZ0`PT>40(I_E/0!3XPPRG^4"((_@`4"@X0,PDN<!0($""-!-X@!0H.$$
M`*#A`#"3Y00PC>4`,*#CAOW_ZPT0H.'<@9_E"("/X`!@H.$%`*#AW/[_ZP"0
M4.)````*??W_ZP``5N$W``":N#&?Y0!PG>4#@)CG!W&@X0`PU>4``%/C/0!3
M$P$PH!,`,*`#!0``"@4PH.$!(//E``!2XST`4A/[__\:!3!#X`(`AN(#`(#@
M`&"8Y57]_^L``%#C!P"&YQ4```H`()CE!0"@X0$PT.0'$)+G``!3XST`4Q,`
M,,'E!@``"@$@@>(!,-#D`A"@X3T`4^,``%,3`3#"Y/G__QH],*#C`2"@X0`P
MP>4!,-3D`3#BY0``4^/[__\:""&?Y?@PG^4"((_@`S"2YP`@D^4$,)WE`B`S
MX``PH.,U```:"-"-XO"'O>@!D$GB`3#4Y`$PZ>4``%/C^___&N[__^K`,)_E
M`X"8YP!PF.4`,)?E``!3XR0```H',*#A!""SY0D0H.$``%+C`9")XOK__QH#
M$('B`1&@X9`PG^4#,(_@`""3Y0``4N,/```:`2"@XP$`H.$`((/E%/W_ZP"@
M4.+5__\*!Q"@X0EQH.$'(*#AS/S_ZP"@B.4`,*#C`)"-Y0&0B>(),8KGHO__
MZ@<`H.'K_/_K``!0XP"@H.$``(CEQ?__"@EQH.'R___J`Y"@X0@0H./?___J
MU?S_ZR#A`0`,`0``[.`!`#@!```,X`$`%.$!`#!`+>EL0)_E;#"?Y01`C^`#
M4)3G#-!-X@``E>5._?_K``"5Y4S]_^M0()_E4#"?Y5`0G^4"()3G`S"/X`$0
MC^`,_?_K``"5Y4/]_^LX,)_E.""?Y3@0G^4#,(_@`,"@XP(@C^`!$(_@"!"-
MZ!;]_^L,T(WB,("]Z/#>`0`4`0``$`$``(QI``#(*0``B"P``#`5``"\*0``
M$$`MZ3!`G^4P,)_E!$"/X`,PE.<``)/E*?W_ZR`@G^4@,)_E(!"?Y0(@E.<#
M,(_@$$"]Z`$0C^#H_/_J6-X!`!0!```0`0```&D``#@I``#<()_E<$`MZ=@P
MG^4"VDWB&-!-X@(@C^`#,)+G`AJ-XA00@>(`,)/E`#"!Y0`PH..[_/_KL!"?
MY;`PG^4,0(WB`1"/X`%JC>*D()_E`S"/X!!@AN(#`(WH`1"@XP0`H.'$_/_K
M!`"@X0$JH.,&$*#AC?S_ZP!`4.(`4*"S"```N@$`A.*:_/_K`%!0X@0```H$
M(*#A!A"@X5G\_^L`,*#C!##%YTP@G^4X,)_E`B"/X`(:C>(#,)+G%!"!X@`@
MD^4`,)'E`B`SX``PH.,#```:!0"@X0+:C>(8T(WB<("]Z%S\_^L`W@$`#`$`
M`!PI```$*0```1```&C=`0"____J6"*?Y?!/+>E4,I_E0MU-X@S03>("((_@
M`&"@X40"G^4#,)+G0LV-XAB`C>(!4*#A``"/X`@0H.$$P(SB`#"3Y0`PC.4`
M,*#CU_W_ZR\0H.,`0*#A!@"@X7W\_^L``%#C$@``"@`"G^4&$*#A``"/X-K^
M_^L&`*#A\"&?Y>`QG^4"((_@0AV-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@
MXVT``!I"W8WB#-"-XO"/O>@&`*#A8/S_ZP"0H.$%`*#A(?S_ZZ@1G^4!$(_@
MD/S_ZP"P4.+B__\*F#&?Y0MPH.$#,(_@%#"-Y8PQG^6,H9_E`S"/X!`PC>4`
M,-?E"J"/X```4^,T```*``!4XP0```H'$*#A!`"@X>3[_^L``%#C.```"@<`
MH.%#_/_K`3!`X@,@U^<#,(?@+P!2XP4``!H`P*#C`,##Y0$@<^4!`$#B+P!2
MX_K__PH!,(GB`#"#X`$*4^.^__^J%"&?Y810C>("((_@"C"@X0$0H.-$`(WI
M!0"@X0$JH.,`<(WE.?S_ZP@0H.$%`*#A]/O_ZP``4.,#```:*#"=Y0\Z`^("
M"5/C&@``"LP0G^4``*#C`1"/X%/\_^L`<*#A``!7XZ3__PH`,-?E``!3X\K_
M_QH``%3C&@``"@`PU.4N`%/C`@``"A1PG>4!`*#CUO__Z@$PU.4``%/C^?__
M&GP0G^4``*#C`1"/X#[\_^L`<*#AZ?__Z@$0H.,%`*#A,_S_ZP``4./?__\:
M5`"?Y040H.$``(_@9O[_ZP4`H.&_^__KB?__ZA!PG>4!`*#COO__ZKW[_^L`
MW0$`#`$``#0H```$*```E-P!`+@G``"`)P``<"<``(@G```<)P``Q"8``'`F
M```T)@```##0Y0``4^,>_R\!`2"`XB\`4^,"`*`!`3#2Y```4^/Z__\:'O\O
MX1!`+>D`0%#B+@``"@`PU.4``%/C*P``"MC[_^L!,$#B`S"$X`,`5.$J```J
M`R"@X0(``.H$`%+A`C"@X24```H",*#A`1!2Y"\`4>/X__\*`P!4X1\``"H!
M,$/B`P!4X1X```H`(-/E+P!2X_G__QH!,$/B`P``Z@`0T^4!,$/B+P!1XP(`
M`!H#`%3A`R"@X?C__SH$($+@`C""X@$*4^,5``"*:`"?Y000H.$``(_@`$"@
MX0$ZH.,!((+B</O_ZP0`H.$0@+WH2`"?Y1!`O>@``(_@;?O_Z@,`5.'C__\:
M`##4Y2\`4^,%```**`"?Y1!`O>@``(_@9/O_Z@``H.,0@+WH%`"?Y1!`O>@`
M`(_@7OO_ZCS;`0#4)```W"0``)@D``#())_ER#2?Y0(@C^!P0"WIP&2?Y0,P
MDN<(T$WBN%2?Y09@C^`-0*#A`#"3Y00PC>4`,*#C!5"/X`00H.$&`*#AX?S_
MZP``4.,.```*C#2?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*
M!#"#X@0@D^4$((/D``!2X_O__QKK___J5&2?Y09@C^`$$*#A!@"@X<O\_^L`
M`%#C#@``"C0TG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P
M@^($()/E!""#Y```4N/[__\:Z___Z@!DG^4&8(_@!!"@X08`H.&U_/_K``!0
MXPX```K<,Y_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B
M!""3Y00@@^0``%+C^___&NO__^JL8Y_E!F"/X`00H.$&`*#AG_S_ZP``4.,.
M```*A#.?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@
MD^4$((/D``!2X_O__QKK___J6&.?Y09@C^`$$*#A!@"@X8G\_^L``%#C#@``
M"BPSG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E
M!""#Y```4N/[__\:Z___Z@1CG^4&8(_@!!"@X08`H.%S_/_K``!0XPX```K4
M,I_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@
M@^0``%+C^___&NO__^JP8I_E!F"/X`00H.$&`*#A7?S_ZP``4.,.```*?#*?
MY0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D
M``!2X_O__QKK___J7&*?Y09@C^`$$*#A!@"@X4?\_^L``%#C#@``"B0RG^4`
M`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```
M4N/[__\:Z___Z@ABG^4&8(_@!!"@X08`H.$Q_/_K``!0XPX```K,,9_E``"=
MY0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C
M^___&NO__^JT89_E!F"/X`00H.$&`*#A&_S_ZP``4.,.```*=#&?Y0``G>4#
M,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O_
M_QKK___J8&&?Y09@C^`$$*#A!@"@X07\_^L``%#C#@``"APQG^4``)WE`S"5
MYP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:
MZ___Z@P!G^4$$*#A``"/X/#[_^L`$%#B`@``"O@`G^4``(_@^/S_Z_``G^4$
M$*#A``"/X.?[_^L`$%#B`@``"MP`G^4``(_@[_S_Z]0`G^4$$*#A``"/X-[[
M_^L`$%#B$@``"L``G^4``(_@YOS_Z[@@G^5D,)_E`B"/X`,PDN<`()/E!#"=
MY0(@,^``,*#C$```&I@0G^68`)_E`1"/X```C^`(T(WB<$"]Z-;\_^J$`)_E
M!!"@X0``C^#%^__K`!!0XNG__PIP`)_E``"/X,W\_^OE___J*?K_ZRS9`0`,
M`0``D"0```#9`0`X`0``,"0``.`C``"4(P``1",``/PB``!`(@``6"(```PB
M``#`(0``["```!@A``#L(```""$```@A```$(0``*"```,C4`0#@(```1"``
M`+`@```T(```G#"?Y9P0G^6<()_E`S"/X`3@+>4!$(_@``"3Y0(@D><,T$WB
M`0!PXP`@DN4$((WE`""@XPH```IP()_E:#"?Y0(@C^`#,)+G`""3Y00PG>4"
M(#/@`#"@XQ```!H,T(WB!/"=Y$@`G^4-$*#A``"/X(?[_^L``%#C!```"@``
MT.4P`%#C``!0$P$`H!,``*`#(#"?Y0,PC^```(/EY?__ZN;Y_^LTU0$`Z-,!
M``P!``"\TP$`4!\``*S4`0`00"WIP/G_Z[GY_^L``%#C``"0%1"`O>@\(9_E
M\$`MZ3@QG^4X89_E`B"/X!S03>(#,)+G!F"/X`!0H.$0$(WB!@"@X0`PD^44
M,(WE`#"@XV#[_^L`0%#B`@``"@`PU.4``%/C#@``&O@@G^7L,)_E`B"/X`,P
MDN<`()/E%#"=Y0(@,^``,*#C,@``&M@`G^4%$*#A``"/X!S0C>+P0+WH6?S_
MZ@40H.&(^?_K``!0XPH```JT()_EH#"?Y0(@C^`#,)+G`""3Y10PG>4"(#/@
M`#"@XQ\``!H<T(WB\("]Z`4`H.'?^?_K`'"@X00`H.'<^?_K``"'X`(`@.+'
M^?_K;""?Y6PPG^4"((_@`S"/X`$0H.,(0(WE!""-Y0!0C>4`(.#C`$"@X=WY
M_^M(()_E*#"?Y0(@C^`#,)+G`""3Y10PG>4"(#/@`#"@XP00H`$&`*`!S___
M"HGY_^L8TP$`#`$``$P?``#0T@$`[!X``(32`0"D'0``I!T```S2`0#`%Y_E
M\$\MZ;PGG^6!W$WB!-!-X@$0C^"P-Y_E'`"-Y0()C>("()'G`S"/X``@DN7\
M((#E`""@X_P`@.('`)/I`7R-XG2`1^(0X(/B*%"#X@<`B.@/`+[H7,!'X@\`
MK.@#`)[H:$!'X@,`C.@'`)7H!P"$Z%@'G^7@8$?B!A"@X0``C^#S^O_K2*>?
MY0J@C^``0%#B`@``"@`PU.4``%/C&P$`&CCY_^LQ^?_K`$!0XO0```H`4)3E
M``!5X_````H%`*#AA_G_ZX``H.$!`(#B<OG_ZP`@U>4``%+C`("@X0P```KP
MMI_E"$"@X0NPC^`$`*#A`""-Y0LPH.$`(.#C`1"@XX;Y_^L!(/7E`D"$X@``
M4N/U__\:P`:?Y5Q01^(``(_@`@``Z@0`M>4``%#C#0``"@80H.'&^O_K`$!0
MXOC__PH`,-3E``!3X_7__PI6^__K``!0X_+__PH$`*#A)/G_ZP!04.(2```:
M`)"@XW2P1^()(8?@=$`2Y0``5.,+```*"5&+X``@U.4``%+C!P``"@0`H.%$
M^__K`9")X@``4.-#```:!$"UY0``5./T__\:`%"@XP4`H.%)^?_K`$"@X0@`
MH.%&^?_K`$"$X`%+A.($0(3B!`"@X2_Y_^O\-9_E`"#@XP,PC^`(,(WE\#6?
MY0$0H.,#,(_@!#"-Y>0UG^4,@(WE`S"/X`!0C>4`@*#A0OG_ZP<=H.,(`*#A
M2/G_ZP$`<.,#```:.?G_ZP`0D.41`%'CJ```&@80H.$(`*#AW/C_ZP!04.(>
M```*F"6?Y1PPG>4"$)KGD"6?Y0``D>4`,)/E`B"/X`$0H.,`@(WE0OG_ZP"@
MH.-T)9_E1#6?Y0(@C^`"&8WB`S"2Y_P0@>(`()/E`#"1Y0(@,^``,*#C1@$`
M&@H`H.&!W(WB!-"-XO"/O>@$`*#AS?C_ZP!04.*J__\*NO__ZM`P%^4/.@/B
M`0E3X]S__QK(L!?EJ?C_ZP``6^'8__\:T#`7Y8,[H.&C.Z#A!PU3X]/__QH$
M`*#AY?C_ZP80H.$`H*#AY`2?Y0``C^!.^O_K`!!0XI,```H<,)WE``"3Y5[\
M_^L`L%#BC@``"@L`H.'I^/_K`P!0XP!`H.$,``":K!2?Y00`0.(``(O@`1"/
MX'[X_^L``%#C!0``&@0`5./>```*!$"+X`4P5.4O`%/CV@``"GQ$G^4$0(_@
M`#"4Y0$`<^-Z```*``!3XX<```ID%)_E9`2?Y0$0C^```(_@-OO_Z\;X_^M4
M-)_E5)2?Y0,PC^`,,(WE3#2?Y4QTG^4#,(_@!#"-Y40TG^5$9)_E`S"/X``@
MX.,!$*#C`("-Y0F0C^`'<(_@!F"/X`@`C>4*`*#AQ_C_ZP\``.K"^/_K`#"0
MY1$`4^,1```:K/C_ZP%0A>(),*#A!""@X0$0H.,0<(WE#%"-Y0"`C>4`P*#A
M0!"-Z0H`H.&V^/_K!QV@XPH`H.&\^/_K`0!PXP!`H.'I__\*"`"@X4[X_^NX
M`Y_E"A"@X0``C^`$^__K"@"@X87^_^M]___J!4"@X6B`1^($,8?@:``3Y0``
M4.,N```*!%&(X`(``.H$`+7E``!0XRD```H&$*#AY_G_ZP%`A.(`,%#B]___
M"@`PT^4``%/C]/__"DCX_^L`4%#B^/[_&NK__^H((Y_E'#"=Y0(`FN<X(Y_E
M`#"3Y0``D.4"((_@!!"-Y0"`C>4!$*#CG?C_ZP"@H.-9___J7_[_ZQ`CG^6H
M,I_E`B"/X`(9C>(#,)+G_!"!X@`@D^4`,)'E`B`SX``PH..?```:!`"@X8'<
MC>($T(WB\$^]Z"?X_^H-`*#C3_C_Z\Q2G^53(*#C!5"/X`"`H.';_O_J'#"=
MY0"PD^5M___JL`*?Y080H.$``(_@L?G_ZP``4.-D```*`##0Y0``4^,P`%,3
M`3"@$P`PH`,!,*`3`#"$%0`PA`5W__\:"P"@X0`0H.,R^/_K`$!0XG+__PH"
M4*#C`##@XQ$@X.,$8$?B`%"-Y2'X_^L&(*#C!A"@X00`H.'A]__K!#!7Y0``
M4^,"```:`S!7Y4,`4^-(```*`#"@XP`@H.,`,(WE!`"@X0`PH.,1^/_KG00`
MZP!0H.$"``#J!A"@X04`H.&\!`#K`BF@XP80H.$$`*#AR_?_ZP`@4.+V___*
M!`"@X41`1^)H^/_K!1"@X00`H.'V!`#KQ)&?Y3!@1^()D(_@!E"@X0$0U.0%
M`*#A`!"-Y0DPH.$`(.#C`1"@XR'X_^L$`%;A`E"%XO7__QJ0,9_E`""@XP,P
MC^`$,(WE"&"-Y0"`C>4(($?E>"&?Y7@QG^4"((_@#""-Y0,PC^``(.#C`1"@
MXPH`H.$.^/_K7/__ZAPPG>4$0)/E``!4XR#__PH$`*#A^/?_ZP,`4.,<__^:
M.!&?Y00`0.(``(3@`1"/X([W_^L``%#C!+"@`13__^H``(3EH?__Z@(P5^5!
M`%/CL___&@$P5^5#`%/CL/__&@`PU^5(`%/CK?__&@$PU^5%`%/CJO__&@`P
MX.,Y(.#C!`"@X0!0C>6]]__K!A"@X2D@H.,$`*#A???_Z\`PG^7`$)_E`S"/
MX`PPC>6X,)_E`1"/X`00C>4#,(_@`"#@XP$0H.,*`*#A"&"-Y0"`C>78]__K
M)O__ZH[W_^NLT0$`#`$``-S2`0"0'```--$!`"P=``"L'```1!P``$`;```8
M'```'`$```@<```\SP$`L!L``'0;``"`SP$`6!H``-@9``#H&P``$!L``&P9
M``"T&P``$!L``$09``"@&```/!D``*#,`0"H&```^!<``*`7``"(%@``V!@`
M``@8``"\%P``%!@``)P5```X%P``=`*?Y702G^4``(_@\$`MZ0$0D.=H,I_E
M#-!-XF0BG^4#,(_@`!"1Y000C>4`$*#C`D"3YPU@H.$``)3EX/?_ZP!0H.$`
M`)3EW??_ZV@@U>4&$*#A`#"@X2P"G^5I(,/E``"/X.3X_^L``%#C`@``"@`P
MT.4Q`%/C8P``"NO[_^L``)3ESO?_ZP`2G^4#,*#C`2"@XP$0C^!O]__K`%!0
MX@L```H``)3EQ??_ZQ`PE>7<(9_E`!"3Y0(@C^!+]__K$#"5Y0`PD^4(,)/E
M`043XUH``!H``)3EN??_Z[01G^4#,*#C`2"@XP$0C^!:]__K`%!0X@L```J<
M`9_E!A"@X0``C^"\^/_K`'!0X@``E.5!```*JO?_ZQ`PE>4'(*#A`!"3Y3'W
M_^L``)3EI/?_ZP!0H.$``)3EH??_ZUP1G^4!(*#C`1"/X%CW_^M0(9_E`B"/
MX``0H.$%`*#A(_?_ZP``E.66]__K`""@XP80H.$P49_E!5"/X``PH.$H`9_E
M:2##Y0``C^";^/_K``!0XP!`H.$(`(7E$@``"@<=H.,$`*#A4/?_ZP$@@.(1
M`%#C`0!2$P`PH.$G``"*[""?Y;@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``P
MH.,=```:#-"-XO"`O>@$`)7E;/W_ZP``4.,`0*#A"`"%Y>;__QJL`)_E``"/
MX#'W_^L!,-#E``!3XYG__PJ7___J:/?_ZY`PG^40()7E`S"/X`0PD^4``)+E
M`!"3Y2[Y_^NY___J``"4Y5[W_^L0,)7E`!"3Y2[W_^N>___JTO;_ZU@@G^58
M`)_E`B"/X`0@DN4``(_@`!"2Y00@H.$5]__K7,D!``P!``!$R0$`%`$``*@4
M```@%@```!8``-@5``#`$P``@!4``(P5``!PR0$`,!,``*#'`0#@%```O,@!
M`(#(`0"<%```3"&?Y4PQG^4"((_@\$`MZ0,PDN<,T$WB`#"3Y00PC>4`,*#C
M`'"@X0;[_^L`,-#E`$"@X0``4^,%```*`2"`XB\`4^,"0*`!`3#2Y```4^/Z
M__\:`&&?Y0!05^(&8(_@`#"6Y0%0H!,!`'/C)@``"@``4^,`4*`#`5`%$@``
M5>,*```:U""?Y<@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,I```:#-"-
MXO"`O>@`,-?E``!3X_'__PJ@$)_E!""@XP$0C^`$`*#A__;_ZP``4./J__\:
MB""?Y70PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,4```:!P"@X0S0C>+P
M0+WH0?C_ZE@`G^4-$*#A``"/X`;X_^L``%#C``"&!=;__PH`,-#E``!3XS``
M4Q,`,*`#`3"@$P`PA@7/__\*`3"@XP`PAN7*___J8_;_ZYC&`0`,`0``B,<!
M`!3&`0!($@``P,4!`$P1````````["N?Y>P[G^4"((_@\$\MZ:/?3>(#,)+G
M#>"@X4#`@.*`8(#B#A"@X0`PD^6$,HWE`#"@XP!0H.,$0!SE"'`<Y20TH.%G
M*"?@_SP#XB0\@^$B)*#A!(2@X00\@^'_+,+C_T@(X@C`C.)G)"+@!#"#X08`
M7.$D`('H"#"!Y0Q0@>40$('BZ___&@C`3>)^[X[B`#"@XPQ`H.%P()SE2)"<
MY700E.4(8+SE3("4Y1APE.4<4)3E"2`BX`1`G.4($"'@!R`BX`8@(N`%$"'@
M!!`AX*)/H.&!0(3A`B"2X`0@@N$.`%SA\"C,X>G__QH(*Y_E`!"=Y0!`D.4@
M<)#E!,"0Y0(0D>`'$)'@I'V@X1#@D.484)#EC'*'X0A@D.6$<H?A#)"0Y0%P
ME^`%$"[@)H&@X080`>`%$"'@"8^(X0%PE^`&CXCA"!"=Y221H.$,GXGA",`N
MX`(0D>`$P`S@#L`LX`40D>`$GXGA#!"1X!#`G>4)H"C@`L"<X`>@"N`(H"K@
M#L"<X.<=@>`*P)S@X:V,X!C`G>6HL)WE`L"<X`C`G.!G@2G@`8`(X`F`*.`(
M@)S@(,"=Y6$1H.$"P)S@"<"<X&>1(>`*D`G@9Y$IX.J-B.`)P)S@Z)V,X"C`
MG>4"P)S@9\&,X&IQ(>`(<`?@`7`GX`?`G.`P<)WE:(&@X0)PE^`!$)?@:G$H
MX`EP!^!J<2?@Z<V,X`<0D>#L?8'@.!"=Y0(0D>!J$8'@::$HX`R@"N`(H"K@
M"A"1X$"@G>5LP:#A`J":X`B`FN!IH2S@!Z`*X&FA*N#G'8'@"H"8X.&MB.!(
M@)WE`H"8X&F!B.!GD2S@`9`)X`R0*>`)@)C@4)"=Y6$1H.$"D)G@#,"9X&>1
M(>`*D`G@9Y$IX.J-B.`)P)S@Z)V,X%C`G>4"P)S@9\&,X&IQ(>`(<`?@`7`G
MX`?`G.!@<)WE:(&@X0)PE^`!$)?@:G$HX`EP!^!J<2?@Z<V,X`<0D>#L?8'@
M:!"=Y0(0D>!J$8'@::$HX`R@"N`(H"K@"A"1X'"@G>5LP:#A`J":X`B`FN!I
MH2S@!Z`*X&FA*N#G'8'@"H"8X.&MB.!X@)WE`H"8X&F!B.!GD2S@`9`)X`R0
M*>`)D)C@@("=Y6$1H.$"@)C@#,"8X&>!(>`*@`C@9X$HX.J=B>`(P)S@Z8V,
MX(C`G>4"P)S@9\&,X&IQ(>`)<`?@`7`GX`?`G."0<)WE:9&@X0)PE^`!$)?@
M:G$IX`AP!^!J<2?@Z,V,X`<0D>#L?8'@F!"=Y0(@D>!H$2G@#!`!X`D0(>!J
M(8+@`2"2X.<=@N"@H)WE("B?Y6S!H.$"H)K@":":X&B1+.`'D"G@"9":X`*@
MF^!HH8K@L+"=Y6>!+.`!@"C@X9V)X`B`FN!A$:#A`J";X`R@FN"XL)WE9\$A
MX`G`+.#IC8C@#,":X`*PF^#HK8S@9W&+X&G!(>#`L)WE",`LX`S`E^!H@:#A
M`G";X`%PE^#(L)WE:1$HX`H0(>#JS8S@`1"7X`)PF^!I<8?@T+"=Y>R=@>!J
M$2C@#!`AX`$0E^!LP:#A`K";X`B`F^!J<2S@V+"=Y0EP)^#I'8'@!W"8X`*`
MF^!J@8C@X+"=Y>&MA^!I<2S@`7`GX`=PF.!A$:#A`H";X`R`F.#HL)WE:<$A
MX`K`+.#J?8?@#,"8X`*`F^!I@8C@\+"=Y>>=C.!JP2'@!\`LX`S`F.!G<:#A
M`H";X`&`F.#XL)WE:A$GX`D0(>#IS8S@`1"8X`*`F^!J@8C@[*V!X&D1)^`,
M$"'@`1"8X`"!G>5LP:#A`H"8X`BQG>4'@)C@:7$LX`IP)^#J'8'@!W"8X`*`
MF^!I@8C@$+&=Y>&=A^!J<2S@`7`GX`=PF.!A$:#A`K";X`S`F^!J@2'@&+&=
MY0F`*.`(@)S@`L";X.E]A^!JP8S@::$AX`>@*N`*H)S@(,&=Y6>QH.$"P)S@
MYXV(X`'`G.!I$2O@"!`AX`$0G.`HP9WEZ*V*X`+`G.#J?8'@:<&,X&@1*^`P
MD9WE"A`AX`'`G.!J$:#A`I"9X`N0F>!HH2'@.+&=Y0>@*N#GS8S@"J"9X`*0
MF^!GL2'@Y"6?Y>RMBN!HD8G@#+`KX&R!H.%`P9WE"["9X&>1B.$"P)S@`<"<
MX`J0">#J'8O@9[$(X`N0B>$)D)S@2,&=Y6JQ".`"P)S@9W&,X&K!B.$!P`S@
M"\",X0?`G.!0<9WEX9V)X`)PE^!A$:#A"'"7X&J!@>%JL0'@"8`(X`N`B.$'
M@)C@6'&=Y>G-C.`"<)?@:J&'X&EQ@>%IL0'@#'`'X`MPA^$*H)?@8'&=Y>R-
MB.`"<)?@;,&@X0%PE^#H'8K@::&,X6FQ#.`(H`K@"Z"*X0=PFN!HH9WE:+$,
MX`*@FN!IH8K@:)&,X0&0">`+D(GA"J"9X'"1G>7A?8?@`I"9X&$1H.$,D)G@
MY\V*X&BA@>%HL0'@!Z`*X`N@BN$)D)K@>*&=Y6>Q`>`"H)K@:*&*X.R-B>!G
MD8'A#)`)X`N0B>$*H)G@@)&=Y6S!H.$"D)G@`9"9X.@=BN!GH8SA9[$,X`B@
M"N`+H(KA"9":X(BAG>5HL0S@`J":X&>ABN#A?8G@:)&,X0&0">`+D(GA"J"9
MX)"1G>5A$:#A`I"9X`R0F>#GS8K@:*&!X6BQ`>`'H`K@"Z"*X0F0FN"8H9WE
M9[$!X`*@FN!HH8K@[(V)X&>1@>$,D`G@"Y")X0J@F>"@D9WE;,&@X0*0F>`!
MD)G@Z!V*X&>AC.%GL0S@"*`*X`N@BN$)D)K@J*&=Y6BQ#.`"H)K@9Z&*X.%]
MB>!HD8SA`9`)X`N0B>$*H)G@L)&=Y6$1H.$"D)G@#)"9X.?-BN!HH8'A:+$!
MX`>@"N`+H(KA"9":X+BAG>5GL0'@`J":X&BABN#LC8G@9Y&!X0R0">`+D(GA
M"J"9X,"1G>5LP:#A`I"9X`&0F>#H'8K@9Z&,X6>Q#.`(H`K@"Z"*X00P@.4)
MD)K@R*&=Y6BQ#.`"H)K@9Z&*X&AQC.$!<`?@"W"'X0IPE^#0H9WEX9V)X`*@
MFN!A$:#A#,":X&BA@>%HL0'@":`*X`N@BN$,P)K@V*&=Y>E]A^`"H)K@:*&*
MX.>-C.!IP8'A:;$!X`?`#.`+P(SAW"*?Y0K`G.#@H9WE9W&@X0*@FN`!H)K@
MZ+&=Y6D1)^`($"'@Z,V,X`$0FN`"L)O@[*V!X&F1B^!H$2?@\+&=Y0P0(>`!
M$)G@;,&@X0*0F^`'D)G@^+&=Y6AQ+.`*<"?@ZAV!X`=PF>`"L)O@X9V'X&B!
MB^!J<2S@`+*=Y0%P)^`'<)C@81&@X0*`F^`,@)C@"+*=Y6K!(>`)P"S@Z7V'
MX`S`F.`"@)O@:H&(X!"RG>7GK8S@:<$AX`?`+.`,P)C@9W&@X0*`F^`!@)C@
M&+*=Y6D1)^`*$"'@ZLV,X`$0F.`"@)O@:8&(X""RG>7LG8'@:A$GX`P0(>`!
M$)C@;,&@X0*`F^`'@)C@*+*=Y6IQ+.`)<"?@Z1V!X`=PF.`"@)O@:H&(X#"R
MG>7AK8?@:7$LX`%P)^`'<)C@81&@X0*`F^`,@)C@.+*=Y6G!(>`*P"S@ZGV'
MX`S`F.`"@)O@:8&(X$"RG>7GG8S@:L$AX`?`+.`,P)C@9W&@X0*`F^`!@)C@
M2+*=Y6H1)^`)$"'@Z<V,X`$0F.`"@)O@:H&(X%"RG>7LK8'@:1$GX`P0(>`!
M$)C@;,&@X0*`F^`'@)C@6+*=Y6EQ+.`*<"?@ZAV!X`=PF.`"@)O@:8&(X&"R
MG>7AG8?@:G$LX`%P)^`'<)C@81&@X0*`F^`,@)C@:L$AX`G`+.#I?8?@#,"8
MX.?-C.!HLIWE;%&%X`*`F^`84(#E:5$AX&J!B.`'4"7@!5"8X.Q=A>!PHIWE
M9W&@X67ACN`"H)K@:8$GX!#@@.5XXIWE#(`HX`$0FN`($)'@`B">X`0@DN!L
MP2?@!<`LX&DA@N`,()+@Y1V!X"#`D.7A+8+@`""`Y080D>!<()_E#'"7X`PP
M@.44,(#E'#"`Y0@0@.4@<(#E)#"`Y2@PG^4"((_@`S"2YP`@D^6$,IWE`B`S
MX``PH.,!```:H]^-XO"/O>A>\__K),4!``P!``"9>8):H>O9;MR\&X_6P6+*
M8+D!`'!`+>F``*#C>_/_ZU10C^+00,7A`""@X_!`P.%,4(_BT$#%X7@@@.7X
M0,#A1%"/XM!`Q>'P0<#A0%"/XM!`Q>'X0<#A/%"/XM!`Q>'P0L#A`$"@XP!0
MH./X0L#A\$/`X7"`O>@``*#A`2-%9P````")J\WO`````/[<NI@`````=E0R
M$`````#PX=+#`````/!'+>DH,)#E`F"@X8;!@^`L()#E`P!<X0`PH.,"(-/@
M`%"@X3`@D.4!0*#A-!"0Y<8/H.$!```J`2"2X@`0H>(L,(7EICZ@X8`Q@^$"
M,)/@H!ZAX'@`E>4X@(7B``!0XRC`A>4P,(7E-!"%Y18``!H_`%;C)0``VD!@
M1N(FDZ#A`7")X@=SA.`$$*#A0""@XP@`H.'X\O_K0$"$X@4`H.&N_/_K!P!4
MX?;__QH)G6G@"6.&X`8@H.$'$*#A"`"@X>WR_^MX8(7E\(>]Z$!P8.(&`%?A
M!G"@H0``B.`'(*#A!!"@X>3R_^MX,)7E`S"'X$``4^-X,(7E\(>]&`4`H.$'
M8$;@!T"$X)3\_^O7___J!'"@X>;__^KP02WI*#"1Y0%`H.%C*"/@,!"1Y2(D
MH.'_+,+C8W0BX&$H(>"C,:#A(B2@X3\P`^+_+,+C860BX`$@@^(X@(3B?Q#@
MXS@`4N,`4*#A`Q#(YP(`B.`[``#:0"!BX@`0H.,H\__K!`"@X7;\_^L(`*#A
M.""@XP`0H.,B\__K!`"@X?!GQ.%O_/_K`S#4Y0`PQ>6R,-3A`3#%Y0`PE.4$
M`*#A(S2@X0(PQ>4`,)3E`S#%Y0LPU.4$,,7ENC#4X04PQ>4(,)3E(S2@X08P
MQ>4(,)3E!S#%Y1,PU.4(,,7ELC'4X0DPQ>40,)3E(S2@X0HPQ>40,)3E"S#%
MY1LPU.4,,,7ENC'4X0TPQ>48,)3E(S2@X0XPQ>48,)3E#S#%Y2,PU.40,,7E
MLC+4X1$PQ>4@,)3E(S2@X1(PQ>4@,)3E$S#%Y?!!O>B#\O_J."!BX@`0H./L
M\O_KR/__ZO!'+>E,8)_E3%"?Y09@C^`%4(_@!6!&X`!PH.$!@*#A`I"@X5CR
M_^M&8;#A\(>]"`!`H.,$,)7D"2"@X0@0H.$'`*#A`4"$XC/_+^$$`%;A]___
M&O"'O>C\M`$`]+0!`![_+^$(,)_E`S"/X``PD^5]\O_J]+8!``A`+>D(@+WH
M`0`"`#L````^````"P```#X````0````/@```"4````^````,P```#X````#
M````/@````8````^````%````#X````.````/@````T````^````)````#X`
M```2````/@```"<````^`````@```#X````8````/@````D````^````"@``
M`#X``````````````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O
M<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0`````%!!4E]04D]'3D%-10``
M```Z````)7,E<R5S```O````4$523#5,24(`````4$523$Q)0@!015),-4]0
M5`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%
M0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````,0```$Q$7TQ)0E)!4EE?
M4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*``!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``
M)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`
M````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4U````56YA8FQE
M('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@`````M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)4@!4
M35``+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[
M,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL
M"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L
M("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF
M("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T
M;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO
M=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z
M.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN
M:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R
M7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I
M;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD
M)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N
M86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT
M(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R
M7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K
M(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D
M(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O
M;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B
M86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA
M;65=*3L*?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB
M.PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@
M("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@
M("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE
M)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@
M/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD
M<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U
M=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM
M>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A
M=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE
M("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E
M<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&-H=6YK7W-I>F4@
M/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@7T9(.PIM>2`D
M;6%G:6-?<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`C($Y/
M5$4Z("1M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW
M:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?<&]S
M+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!
M4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)
M0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?
M<&]S("T]("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO
M=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I
M;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U
M;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*;7D@
M)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O
M;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@-"`M("1O9F9S970L(#`["B1D871A7W!O<R`]('1E;&P@7T9(
M.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@
M("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW
M:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE
M(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN
M+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI
M+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D
M8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD
M969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O
M:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F
M+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@
M)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@
M/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI
M8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M
M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^
M8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E
M:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I
M;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z
M("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IU;FQE<W,@*"1B=68@97$@
M(E!+7#`P,UPP,#0B*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)
M3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@
M.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@
M("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D
M8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%2
M7T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R
M:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'
M?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T
M:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI
M8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@
M("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2![
M"B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D
M,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*
M)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD
M;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$[
M"GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@
M;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L
M<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`
M05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I
M<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS
M:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@
M1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II
M<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D
M<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=
M('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG
M="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P
M;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.
M5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI
M+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I
M;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O
M("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T10
M04XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\
M(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$
M>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY
M("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@
M(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA
M;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]
M"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@
M;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H
M+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@
M:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD
M("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q
M6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@
M>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@
M/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*
M8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N
M=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N
M9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H
M<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP
M+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B
M73L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`[
M"FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M
M>2`D=&@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)'1H*3L*8VQO
M<V4@)'1H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C
M:&5?;F%M92`N/2`B7#`B('@@*#0P("T@;&5N9W1H("1C86-H95]N86UE*3L*
M)&-A8VAE7VYA;64@+CT@(EPP0T%#2$4B.PIM>2`D;V9F<V5T(#T@)&9H+3YT
M96QL("L@;&5N9W1H*"1C86-H95]N86UE*2`M(&QE;F=T:"@D;&]A9&5R*3L*
M)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*<&%C:R@G3B<L("1O9F9S970I+`HD
M4$%27TU!1TE#*0HF)B`D9F@M/F-L;W-E"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70[
M"F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F
M:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E
M<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G
M<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;W5T<R@B4F5A9&EN9R!-151!+GEM;"XN+B(I.PII
M9B`H;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD
M;65T82`]?B!S+RXJ7G!A<CI<<RHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["FEF("AM>2`H)&-L96%N*2`]("1M971A(#U^("]>7',K8VQE86XZ("@N
M*BDD+VTI('L*)&-L96%N(#U^("]>7',J?%QS*B0O9SL*)$5.5GM005)?0TQ%
M04Y](#T@,2!I9B`D8VQE86X["GT*?0IP=7-H($!005(Z.DQI8D-A8VAE+"`D
M>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B
M17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@
M;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E
M<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I
M;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H
M;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@
M>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;
M17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]
M?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@
M)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D
M(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP
M9&ER("X]("(D<WES>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*;7D@
M)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X
M(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L
M("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@
M)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE
M>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D<WES>U]D96QI
M;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]=&5M
M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@
M7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\[
M"FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE
M("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*
M;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R
M:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D
M=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@
M)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U
M;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.
M5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N
M*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF
M("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!
M4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE
M+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@
M*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES
M>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G
M;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE
M)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R
M;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E
M<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?
M5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<
M421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?
M9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M
M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R
M;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%
M?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*
M)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P
M=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ
M("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@
M.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<
M+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV
M('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U
M<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R
M("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%
M("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$
M25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.
M5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,
M7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!
M4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF
M("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I
M;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<[
M"G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG
M>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S
M:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C
M:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ
M9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N
M<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U
M8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*
M9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@
M/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z
M.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P```#L````^````"P``
M`#X````0````/@```"4````^````,P```#X````#````/@````8````^````
M%````#X````.````/@````T````^````)````#X````2````/@```"<````^
M`````@```#X````8````/@````D````^````"@```#X``````````````+"-
M_W\!````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!0&0``Z!@```$````;`P```0```"L#```!````.P,```$```!%`P``
M#````"P2```-````&$D``!D```"L_0$`&P````0````:````L/T!`!P````$
M````]?[_;ZP!```%````3`D```8```"<`@``"@```-($```+````$````!4`
M`````````P```,3^`0`"````Z`$``!0````1````%P```$00```1````9`\`
M`!(```#@````$P````@````>````"````/O__V\!```(_O__;_0.``#___]O
M`P```/#__V\>#@``^O__;Q``````````````````````````````````````
M````````````````````M/T!````````````.!(``#@2```X$@``.!(``#@2
M```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(`
M`#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``
M.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X
M$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2
M```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(`
M``!)`````````````````````````````````````````````*!(````````
M*!4````````````````````````$``(`_____]1,```02@```````-!*``#4
M2@``R$P``!A*``#03````````+1,``"\3````````-Q,``!'0T,Z("A$96)I
M86X@,3$N,RXP+30I(#$Q+C,N,`!!*@```&%E86)I``$@````!35410`&!`@!
M"0$2!!,!%`$5`1<#&`$9`1H"`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR
M96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O
M=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````
M```````````````````````````````````````````````+`````0````(`
M``!4`0``5`$``!,```````````````$`````````$P````<````"````:`$`
M`&@!```D```````````````$`````````"8````'`````@```(P!``",`0``
M(```````````````!``````````T````]O__;P(```"L`0``K`$``/`````%
M``````````0````$````/@````L````"````G`(``)P"``"P!@``!@````,`
M```$````$````$8````#`````@```$P)``!,"0``T@0``````````````0``
M``````!.````____;P(````>#@``'@X``-8````%``````````(````"````
M6P```/[__V\"````]`X``/0.``!P````!@````,````$`````````&H````)
M`````@```&0/``!D#P``X`````4`````````!`````@```!S````"0```$(`
M``!$$```1!```.@!```%````%0````0````(````?`````$````&````+!(`
M`"P2```,```````````````$`````````'<````!````!@```#@2```X$@``
M\`(`````````````!`````0```""`````0````8````H%0``*!4``/`S````
M``````````@`````````B`````$````&````&$D``!A)```(````````````
M```$`````````(X````!`````@```"!)```@20``"$$`````````````!```
M``````"6`````0``<((````HB@``*(H```@````-``````````0`````````
MH0````$````"````,(H``#"*```$```````````````$`````````*L````.
M`````P```*S]`0"L_0``!```````````````!`````0```"W````#P````,`
M``"P_0$`L/T```0```````````````0````$````PP````8````#````M/T!
M`+3]```0`0``!@`````````$````"````,P````!`````P```,3^`0#$_@``
M/`$`````````````!`````0```#1`````0````,```````(````!`$``````
M``````````0`````````UP````@````#````0``"`$```0`4$```````````
M```$`````````-P````!````,`````````!```$`'@```````````````0``
M``$```#E`````P``<```````````7@`!`"L```````````````$`````````
H`0````,``````````````(D``0#U```````````````!````````````
